==> katana_routing-0.8.1%2B6.tar.gz: lib/src/extensions.dart <==
part of katana_routing;

extension NavigatorStateExtensions on NavigatorState {
  /// Pops the page to the page with the specified path.
  ///
  /// Enter the pathname of the page in [name].
  Future<void> popUntilNamed(String name) async {
    popUntil((route) {
      return route.settings.name == name;
    });
  }

  /// Reset all history and go to a specific page.
  ///
  /// After all pages are [pop()],
  /// the page specified by [newRouteName] is [pushNamed()].
  ///
  /// In [arguments], put [RouteQuery] and so on.
  ///
  /// Ideal for moving after logging out.
  Future<T?> resetAndPushNamed<T extends Object?>(
    String newRouteName, {
    Object? arguments,
  }) {
    return pushNamedAndRemoveUntil(
      newRouteName,
      (route) => false,
      arguments: arguments,
    );
  }
}

extension BuildContextExtensions on BuildContext {
  /// Explicitly rebuild the widget.
  ///
  /// Basically, do not use it.
  ///
  /// Use this only if you want to force a rebuild.
  void rebuild() {
    UIScope.of(this).rebuild();
  }

  /// Outputs the theme related to the context.
  ThemeData get theme => Theme.of(this);

  /// Outputs the widget theme related to the context.
  WidgetTheme get widgetTheme => WidgetTheme.of(this);

  /// Get the Navigator related to context.
  NavigatorState get navigator => Navigator.of(this);

  /// Get the Root navigator related to context.
  NavigatorState get rootNavigator => Navigator.of(this, rootNavigator: true);

  /// Get the Flavor.
  String get flavor => FlavorScope.of(this).flavor;

  /// Get the data passed to the page.
  ///
  /// Basically it returns the [RouteQuery] data passed from the previous page.
  ///
  /// If the [RouteQuery] data is not found,
  /// the map stored in [PageHookWidget] is retrieved.
  Map<String, dynamic> get arg =>
      ModalRoute.of(this)?.settings.arguments as Map<String, dynamic>? ??
      UIScope.of(this)._map;

  /// Gets the value from the [key] of the map stored in [arg].
  ///
  /// If [key] does not exist in the map, [orElse] is returned.
  T get<T>(String key, T orElse) {
    return arg.get(key, orElse);
  }

  /// Save [value] to [key] of the map stored in [arg].
  ///
  /// The data will be unique within the page and can continue to be used even if the widget is rebuilt.
  void operator []=(String key, dynamic value) {
    arg[key] = value;
  }

  /// Get the media qury related to context
  MediaQueryData get mediaQuery => MediaQuery.of(this);

  /// Releases focus such as text field.
  void unfocus() {
    FocusScope.of(this).requestFocus(FocusNode());
  }
}

==> katana_routing-0.8.2%2B6.tar.gz: lib/src/extensions.dart <==
part of katana_routing;

extension NavigatorStateExtensions on NavigatorState {
  /// Pops the page to the page with the specified path.
  ///
  /// Enter the pathname of the page in [name].
  Future<void> popUntilNamed(String name) async {
    popUntil((route) {
      return route.settings.name == name;
    });
  }

  /// Reset all history and go to a specific page.
  ///
  /// After all pages are [pop()],
  /// the page specified by [newRouteName] is [pushNamed()].
  ///
  /// In [arguments], put [RouteQuery] and so on.
  ///
  /// Ideal for moving after logging out.
  Future<T?> resetAndPushNamed<T extends Object?>(
    String newRouteName, {
    Object? arguments,
  }) {
    return pushNamedAndRemoveUntil(
      newRouteName,
      (route) => false,
      arguments: arguments,
    );
  }
}

extension BuildContextExtensions on BuildContext {
  /// Explicitly rebuild the widget.
  ///
  /// Basically, do not use it.
  ///
  /// Use this only if you want to force a rebuild.
  void rebuild() {
    UIScope.of(this).rebuild();
  }

  /// Rebuild all active pages.
  ///
  /// Basically, do not use it.
  ///
  /// Use this only if you want to force a rebuild.
  void rebuildAll() {
    UIScope.of(this).rebuildAll();
  }

  /// Rebuild only the pages that are `true` in [test].
  ///
  /// Normally, you should check if you want to rebuild based on the page name.
  /// ```
  /// context.rebuildWhere((page) {
  ///   return page.routeSettings?.name == "/";
  /// });
  /// ```
  ///
  /// Basically, do not use it.
  ///
  /// Use this only if you want to force a rebuild.
  void rebuildWhere(bool Function(PageState page) test) {
    UIScope.of(this).rebuildWhere(test);
  }

  /// Open a new URL or screen.
  ///
  /// If [path] starts with `http`,
  /// it opens a browser, otherwise it opens a screen path.
  ///
  /// It is possible to configure the settings for
  /// opening the screen by specifying [query].
  Future<T?> open<T extends Object?>(String path, [RouteQuery? query]) async {
    if (path.startsWith("http")) {
      await openURL(path);
      return null;
    } else {
      return await navigator.pushNamed(path, arguments: query);
    }
  }

  /// Outputs the theme related to the context.
  ThemeData get theme => Theme.of(this);

  /// Outputs the widget theme related to the context.
  WidgetTheme get widgetTheme => WidgetTheme.of(this);

  /// Get the Navigator related to context.
  NavigatorState get navigator => Navigator.of(this);

  /// Get the Root navigator related to context.
  NavigatorState get rootNavigator => Navigator.of(this, rootNavigator: true);

  /// Get the Flavor.
  String get flavor => FlavorScope.of(this).flavor;

  /// Get the route settins.
  RouteSettings get route =>
      ModalRoute.of(this)?.settings ?? const RouteSettings();

  /// Get the data passed to the page.
  ///
  /// Basically it returns the [RouteQuery] data passed from the previous page.
  ///
  /// If the [RouteQuery] data is not found,
  /// the map stored in [PageHookWidget] is retrieved.
  DynamicMap get arg =>
      ModalRoute.of(this)?.settings.arguments as DynamicMap? ??
      UIScope.of(this)._map;

  /// Gets the value from the [key] of the map stored in [arg].
  ///
  /// If [key] does not exist in the map, [orElse] is returned.
  T get<T>(String key, T orElse) {
    return arg.get(key, orElse);
  }

  /// Save [value] to [key] of the map stored in [arg].
  ///
  /// The data will be unique within the page and can continue to be used even if the widget is rebuilt.
  void operator []=(String key, dynamic value) {
    arg[key] = value;
  }

  /// Get the media qury related to context
  MediaQueryData get mediaQuery => MediaQuery.of(this);

  /// Releases focus such as text field.
  void unfocus() {
    FocusManager.instance.primaryFocus?.unfocus();
  }
}

extension ThemeExtension on ThemeData {
  /// Text color.
  Color get textColor {
    return colorScheme.onBackground;
  }

  /// Text color on primary.
  Color get textColorOnPrimary {
    return colorScheme.onPrimary;
  }

  /// Text color on secondary.
  Color get textColorOnSecondary {
    return colorScheme.onSecondary;
  }

  /// Text color on surface.
  Color get textColorOnSurface {
    return colorScheme.onSurface;
  }

  /// Text color on error.
  Color get textColorOnError {
    return colorScheme.onError;
  }
}
